@@ -15,7 +15,7 @@ class CloudXSetup:
     
     def __init__(self, profile: str = "vscode", ssh_key: str = "vscode", ssh_config: str = None, 
                  aws_env: str = None, use_1password: str = None, instance_id: str = None, 
-                 non_interactive: bool = False):
+                 non_interactive: bool = False, dry_run: bool = False):
         """Initialize cloudx-proxy setup.
         
         Args:
@@ -26,6 +26,7 @@ class CloudXSetup:
             use_1password: Use 1Password SSH agent for authentication. Can be True/False or a vault name (default: None)
             instance_id: EC2 instance ID to set up connection for (optional)
             non_interactive: Non-interactive mode, use defaults for all prompts (default: False)
+            dry_run: Preview mode, show what would be done without executing (default: False)
         """
         self.profile = profile
         self.ssh_key = ssh_key
@@ -43,6 +44,7 @@ class CloudXSetup:
             self.op_vault = use_1password
         self.instance_id = instance_id
         self.non_interactive = non_interactive
+        self.dry_run = dry_run
         self.home_dir = str(Path.home())
         self.onepassword_agent_sock = Path(self.home_dir) / ".1password" / "agent.sock"
         
@@ -134,6 +136,13 @@ class CloudXSetup:
         Returns:
             bool: True if profile was set up successfully or user chose to continue
         """
+        if self.dry_run:
+            self.print_status(f"[DRY RUN] Would check AWS profile configuration for '{self.profile}'")
+            if self.aws_env:
+                self.print_status(f"[DRY RUN] Would configure AWS environment: {self.aws_env}", None, 2)
+            self.print_status(f"[DRY RUN] Would verify AWS credentials and extract cloudX environment", None, 2)
+            return True
+            
         self.print_status("Checking AWS profile configuration...")
         
         try:
@@ -164,18 +173,38 @@ class CloudXSetup:
             # Verify the profile works
             try:
                 identity = session.client('sts').get_caller_identity()
-                user_arn = identity['Arn']
-                
-                # Extract environment from IAM user name
-                user_parts = [part for part in user_arn.split('/') if part.startswith('cloudX-')]
-                if user_parts:
-                    self.default_env = user_parts[0].split('-')[1]  # Extract env from cloudX-{env}-{user}
-                    self.print_status(f"AWS profile '{self.profile}' exists and matches cloudX format", True, 2)
-                    return True
-                else:
-                    self.print_status(f"AWS profile exists but doesn't match cloudX-{{env}}-{{user}} format", False, 2)
+                identity_arn = identity['Arn']
+
+                # Determine if the identity refers to an IAM user or an assumed role/SSO session
+                resource = identity_arn.split(':', 5)[5]  # arn:partition:service:region:account:resource
+                resource_type, _, resource_details = resource.partition('/')
+
+                if resource_type == 'user' and resource_details:
+                    path_segments = [segment for segment in resource_details.split('/') if segment]
+                    cloudx_segment = next(
+                        (segment for segment in reversed(path_segments) if segment.startswith('cloudX-')),
+                        None,
+                    )
+
+                    if cloudx_segment:
+                        # Extract env from cloudX-{env}-{user}
+                        parts = cloudx_segment.split('-')
+                        if len(parts) >= 3:
+                            self.default_env = parts[1]
+                        self.print_status(f"AWS profile '{self.profile}' exists and matches cloudX format", True, 2)
+                        return True
+
+                    self.print_status(
+                        "AWS profile exists but doesn't match cloudX-{env}-{user} format", False, 2
+                    )
                     self.print_status("Please ensure your IAM user follows the format: cloudX-{env}-{username}", None, 2)
                     return False
+
+                # Non-user identities (roles, SSO, etc.) should skip the cloudX naming check
+                self.print_status(
+                    "AWS profile uses IAM role/SSO credentials; skipping cloudX user format check", True, 2
+                )
+                return True
             except ClientError:
                 self.print_status("Invalid AWS credentials", False, 2)
                 return False
@@ -362,6 +391,16 @@ class CloudXSetup:
         """
         self.print_header("SSH Key Configuration")
         
+        if self.dry_run:
+            self.print_status(f"[DRY RUN] Would check SSH key '{self.ssh_key}' configuration")
+            if self.use_1password:
+                self.print_status(f"[DRY RUN] Would use 1Password SSH agent for authentication", None, 2)
+                self.print_status(f"[DRY RUN] Would create or find SSH key in vault: {self.op_vault}", None, 2)
+            else:
+                self.print_status(f"[DRY RUN] Would create SSH key pair at: {self.ssh_key_file}", None, 2)
+                self.print_status(f"[DRY RUN] Would set proper file permissions", None, 2)
+            return True
+        
         # Check 1Password integration if requested
         if self.use_1password:
             op_available = self._check_1password_availability()
@@ -387,16 +426,27 @@ class CloudXSetup:
             if not self._set_directory_permissions(self.ssh_dir):
                 return False
             
-            key_exists = self.ssh_key_file.exists() and (self.ssh_key_file.with_suffix('.pub')).exists()
+            pub_key_file = self.ssh_key_file.with_suffix('.pub')
+            private_key_exists = self.ssh_key_file.exists()
+            pub_key_exists = pub_key_file.exists()
+            
+            # Check if only public key exists (private key likely in 1Password)
+            if pub_key_exists and not private_key_exists:
+                self.print_status(f"Public key '{self.ssh_key}.pub' found (private key in 1Password or secure storage)", True, 2)
+                self.print_status("Using existing key configuration", True, 2)
+                return True
+            
+            key_exists = private_key_exists and pub_key_exists
             
             if key_exists:
-                self.print_status(f"SSH key '{self.ssh_key}' exists", True, 2)
+                self.print_status(f"SSH key pair '{self.ssh_key}' already exists", True, 2)
                 # Set proper permissions on existing key files
                 if platform.system() != 'Windows':
                     import stat
                     self.ssh_key_file.chmod(stat.S_IRUSR | stat.S_IWUSR)  # 600 permissions (owner read/write)
-                    self.ssh_key_file.with_suffix('.pub').chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IROTH | stat.S_IRGRP)  # 644 permissions
-                    self.print_status("Set key file permissions", True, 2)
+                    pub_key_file.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IROTH | stat.S_IRGRP)  # 644 permissions
+                    self.print_status("Updated key file permissions", True, 2)
+                self.print_status("Using existing SSH key", True, 2)
             else:
                 self.print_status(f"Generating new SSH key '{self.ssh_key}'...", None, 2)
                 subprocess.run([
@@ -405,17 +455,15 @@ class CloudXSetup:
                     '-f', str(self.ssh_key_file),
                     '-N', ''  # Empty passphrase
                 ], check=True)
-                self.print_status("SSH key generated", True, 2)
+                self.print_status("SSH key generated successfully", True, 2)
                 
                 # Set proper permissions on newly generated key files
                 if platform.system() != 'Windows':
                     import stat
                     self.ssh_key_file.chmod(stat.S_IRUSR | stat.S_IWUSR)  # 600 permissions (owner read/write)
-                    self.ssh_key_file.with_suffix('.pub').chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IROTH | stat.S_IRGRP)  # 644 permissions
+                    pub_key_file.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IROTH | stat.S_IRGRP)  # 644 permissions
                     self.print_status("Set key file permissions", True, 2)
             
-            # Standard key generation successful
-            self.print_status("Key generated successfully", True, 2)
             return True
 
         except Exception as e:
@@ -507,14 +555,16 @@ Host cloudx-*
 """
         
         # Add SSH multiplexing configuration
+        # On Windows, the default SSH client doesn't support Control* options,
+        # so we comment them out by default. Users with alternative SSH clients
+        # (like the one from Git for Windows) can uncomment these if needed.
         control_path = "~/.ssh/control/%r@%h:%p"
-        if platform.system() == 'Windows':
-            # Use forward slashes for Windows as well, SSH client will handle conversion
-            control_path = "~/.ssh/control/%r@%h:%p"
-            
-        config += f"""    ControlMaster auto
-    ControlPath {control_path}
-    ControlPersist 4h
+        is_windows = platform.system() == 'Windows'
+        comment_prefix = "# " if is_windows else ""
+        
+        config += f"""    {comment_prefix}ControlMaster auto
+    {comment_prefix}ControlPath {control_path}
+    {comment_prefix}ControlPersist 4h
 """
         
         return config
@@ -790,6 +840,15 @@ Host cloudx-{cloudx_env}-{hostname}
             bool: True if config was set up successfully
         """
         self.print_header("SSH Configuration")
+        
+        if self.dry_run:
+            self.print_status(f"[DRY RUN] Would set up SSH configuration with three-tier approach")
+            self.print_status(f"[DRY RUN] Would create generic pattern: cloudx-*", None, 2)
+            self.print_status(f"[DRY RUN] Would create environment pattern: cloudx-{cloudx_env}-*", None, 2)
+            self.print_status(f"[DRY RUN] Would create host entry: cloudx-{cloudx_env}-{hostname} -> {instance_id}", None, 2)
+            self.print_status(f"[DRY RUN] Would write configuration to: {self.ssh_config_file}", None, 2)
+            return True
+        
         self.print_status("Setting up SSH configuration with three-tier approach...")
         
         try:
@@ -953,6 +1012,24 @@ Host cloudx-{cloudx_env}-{hostname}
         """
         self.print_header("Instance Access Check")
         
+        if self.dry_run:
+            self.print_status(f"[DRY RUN] Would check instance accessibility for: {hostname}")
+            self.print_status(f"[DRY RUN] Would test connection to instance: {instance_id}", None, 2)
+            self.print_status(f"[DRY RUN] Would wait up to 5 minutes for SSH access if needed", None, 2)
+            return True
+        
+        # On Windows, skip the automated connection test as it may hang
+        # Instead, provide clear instructions for manual testing
+        if platform.system() == 'Windows':
+            self.print_status("Skipping automated connection test on Windows", None, 2)
+            print(f"\n\033[96m{'='*60}\033[0m")
+            print(f"\033[96mSetup completed! To test your SSH connection, run:\033[0m")
+            print(f"\n  \033[1mssh cloudx-{cloudx_env}-{hostname}\033[0m")
+            print(f"\n\033[96m{'='*60}\033[0m\n")
+            self.print_status("Configuration files have been created successfully", True, 2)
+            return True
+        
+        # On non-Windows systems, proceed with automated connection test
         if self.check_instance_setup(instance_id, hostname, cloudx_env):
             return True
             
